==> tiki_login-0.0.10.tar.gz: lib/src/modal_recover/ui/modal_recover_ui_view.dart <==
/*
 * Copyright (c) TIKI Inc.
 * MIT license. See LICENSE file in root directory.
 */

import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import '../../utils/utils_icons.dart';
import '../modal_recover_controller.dart';
import '../modal_recover_service.dart';
import '../modal_recover_style.dart';

abstract class ModalRecoverUiView extends StatelessWidget {
  late final ModalRecoverStyle style;
  late final ModalRecoverController controller;

  ModalRecoverUiView({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    ModalRecoverService service =
        Provider.of<ModalRecoverService>(context, listen: false);
    style = service.style;
    controller = service.controller;
    return Container(
        padding: EdgeInsets.only(top: style.size(8)),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                TextButton(
                    onPressed: () => back(context),
                    child: Icon(UtilsIcons.arrow,
                        size: style.modalNavIconSize,
                        color: style.modalNavColor)),
                TextButton(
                    onPressed: () => controller.close(context),
                    child: Icon(UtilsIcons.x,
                        size: style.modalNavIconSize,
                        color: style.modalNavColor))
              ],
            ),
            page(context)
          ],
        ));
  }

  Widget page(BuildContext context);

  void back(BuildContext context);
}

==> tiki_login-0.0.13.tar.gz: lib/src/modal_recover/ui/modal_recover_ui_view.dart <==
/*
 * Copyright (c) TIKI Inc.
 * MIT license. See LICENSE file in root directory.
 */

import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:tiki_style/tiki_style.dart';

import '../modal_recover_controller.dart';
import '../modal_recover_service.dart';

abstract class ModalRecoverUiView extends StatelessWidget {
  late final ModalRecoverController controller;

  ModalRecoverUiView({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    ModalRecoverService service =
        Provider.of<ModalRecoverService>(context, listen: false);
    controller = service.controller;
    return Container(
        padding: EdgeInsets.only(top: SizeProvider.instance.height(8)),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                TextButton(
                    onPressed: () => back(context),
                    child: Icon(IconProvider.arrow_left,
                        size: SizeProvider.instance.text(16),
                        color: ColorProvider.greyThree)),
                TextButton(
                    onPressed: () => controller.close(context),
                    child: Icon(IconProvider.x,
                        size: SizeProvider.instance.text(16),
                        color: ColorProvider.greyThree))
              ],
            ),
            page(context)
          ],
        ));
  }

  Widget page(BuildContext context);

  void back(BuildContext context);
}
